A Starting Point: Some Introductory Comments
Description
Some pointers to a few key functions in BQTLNew to R?
- Be sure to check out all of the free documentation
that comes with R.
- The
examplefunction is very
helpful in getting familiar with a new function. You typeexample(fun)and the examples in the documentation forfunare run, then you can read the documentaiton to get a bette
sense of what is really going on. My personal favorite is to typepar(ask=T), hit the 'enter' key, thenexample(image),
and 'enter' again; after each display you hit the 'enter' key to get
to the next one. library(bqtl)is needed to load theBQTLfunctions and data
sets.