linear.bayes can be improved by
performing Laplace approximations. This function is a development
version of a wrapper to do that for all of the returned by
linear.bayes.adjust.linear.bayes(lbo, ana.obj=lbo$call$ana.obj, ...)linear.bayesanalysis.object used to create
lbo. This need not be given explicitly, iff the original
version is in the search path."adjust.linear.bayes" containing:adjust.linear.bayeslinear.bayes