coef.bqtl: Extract Coefficients from fitted objects
Description
Return a vector or matrix of coefficients as appropriateUsage
## S3 method for class 'bqtl':
coef(object)
Arguments
object
The object returned by bqtl.
Value
- A vector (if
bqtl returned a single fit) or matrix (if
bqtl returned a list with more than one fit)
synopsis
coef.bqtl(object,...)