covar: Treat locus as covariate
Description
Sometimes it is helps speed computations to linearize the likelihood
or at least a part of it w.r.t. the locus allele values. Both
'Haley-Knott regression' and 'composite interval mapping' use this
approach. covar provides a mechanism for creating formula
objects that specify such linearizations.Arguments
x
The name of a locus (except for F2 designs, when it is the
name of an effect like 'add.m.32') or any argument of the sort that
locus allows. If x evaluates to a single value,
then Value
- a character string or vector
Details
The function covar actually only returns x. The real
work is done by a covar function that is hidden inside of
bqtl, where the arguments are parsed as for locus. Each
of the return values from locus is prefixed by "covar(" and
suffixed by ")". If x is a name of a locus or effect, then
paste("covar(",deparse(x),")") is returned. Later, when
bqtl calls lapadj, terms like covar(PVV4.1) are
recognized as requiring a linearization w.r.t. effect 'PVV4.1'.References
HALEY, C. S. and S. A. KNOTT, 1992 A simple regression method for
mapping quantitative trait loci in line crosses using flanking
markers. Heredity 69:315-324.
Knapp SJ, Bridges WC, and Birkes D. Mapping quantitative trait loci
using molecular marker linkage maps. Theoretical and Applied Genetics
79: 583-592, 1990.
ZENG, Z.-B., 1994 Precision mapping of quantitative trait
loci. Genetics 136:1457-1468