Learn R Programming

bqtl (version 1.0-36)

residuals.bqtl: Residuals from QTL models

Description

The phenotype data, estimated coefficients, and expected locus values are used to find fitted values for the QTL model

Usage

# S3 method for bqtl
residuals(object,...)

Value

A vector with as many elements trait values used in the original fitted model.

Arguments

object

An object of class bqtl

...

ignored

Author

Charles C. Berry cberry@ucsd.edu

Details

The estimated coefficients for a specific QTL model fit are used along with the expected locus values (conditionally on the marker values) are used to find fitted values for the QTL model; these are subtracted from the origianl trait values to get residuals. This is not the only way in which such fits could be obtained; one could condition the expected marker values on both the trait value and the marker values. One could also define fitted values for specific genotype combinations, e.g. for a backcross with k animals and a two gene model 4 fitted values could be determined for each animal leading to 2*2*k residuals.

See Also

bqtl

Examples

Run this code

data(little.ana.bc)

fit.pheno <- bqtl(bc.phenotype~locus(15)+locus(42),little.ana.bc)

summary(residuals(fit.pheno))

plot( fitted( fit.pheno ), residuals( fit.pheno) )

rm(little.ana.bc,fit.pheno)

Run the code above in your browser using DataLab