swap are much improved
by the use a Laplace approximations for loci that are not
markers. This function combines the results of a call like
bqtl(y~configs(swap.obj),...) with the data in
swap.obj to provide improved posteriors, et ceterasummary.adj(adj.obj, n.loc, coef.znames, mode.names=c("add", "dom"), imp.denom=NULL, swap.obj=NULL)bqtl(y~configs(swap.obj),...)map.names for the sample spaceNULL except for "F2", in which case it is
uusally c("add","dom")adj.objswapadj