The estimated coefficients for a specific QTL model fit are used along
with the expected locus values (conditionally on the marker values)
are used to find fitted values for the QTL model; these are subtracted
from the origianl trait values to get residuals. This is not the
only way in which such fits could be obtained; one could condition the
expected marker values on both the trait value and the marker
values. One could also define fitted values for specific genotype
combinations, e.g. for a backcross with k animals and a two gene model
4 fitted values could be determined for each animal leading to 2*2*k
residuals.